@@ -17,13 +17,13 @@ on and off.
 The other classes of this portion are used to overlay or augment the app’s user interface with product tours, tutorials,
 walkthroughs and user onboarding/welcome features.
 
-The :class:`AnimatedTourMixin` can be mixed-into a tour class that inherits from :class:`~ae.gui_help.TourBase` for to
+The :class:`AnimatedTourMixin` can be mixed-into a tour class that inherits from :class:`~ae.gui_help.TourBase` to
 extend it with animation and glsl shader features.
 
 The class :class:`AnimatedOnboardingTour` is providing an app onboarding tour that covers the core features and can be
 easily extended with app-specific tour pages.
 
-Finally, the class :class:`TourOverlay` is implementing a overlay layout widget for to display the animations, shaders,
+Finally, the class :class:`TourOverlay` is implementing a overlay layout widget to display the animations, shaders,
 tour page texts, tooltip text and the navigation buttons of an active/running app tour.
 
 
@@ -143,7 +143,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.1.26'
+__version__ = '0.1.27'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -217,7 +217,7 @@ class ModalBehavior:
         """
         if App.get_running_app().main_app.help_activator.collide_point(*touch.pos):
             return False  # allow help activator button to process this touch down event
-            # .. and leave self._touch_started_inside == None for to not initiate popup.close/dismiss in on_touch_up
+            # .. and leave self._touch_started_inside == None to not initiate popup.close/dismiss in on_touch_up
         self._touch_started_inside = self.collide_point(*touch.pos)
 
         # pylint: disable=superfluous-parens # false positive
@@ -390,7 +390,7 @@ class HelpToggler(ReliefCanvas, Image):
 
 
 class AnimatedTourMixin:        # (TourBase):
-    """ tour class mixin for to add individual shaders to the tour layout and their children widgets. """
+    """ tour class mixin to add individual shaders to the tour layout and their children widgets. """
     # abstracts
     layout: Widget
     main_app: Any
@@ -662,7 +662,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
         layout.ani_value = 0.0
         super().next_page()
         if self.last_page_id == '' and self.pages_animations.pop('', False):
-            Animation(font_size=layout.font_height).start(layout.ids.next_but)
+            Animation(font_size=layout.font_height).start(layout.ids.next_but)  # set font size back to original value
 
     def setup_layout(self):
         """ overridden to update layout texts if app window/screen orientation (app.landscape) changes. """
@@ -727,7 +727,7 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
     """
 
     def __init__(self, main_app: HelpAppBase, tour_class: Optional[Type['TourBase']] = None, **kwargs):
-        """ prepare app and tour overlay (singleton instance of this class) for to start tour.
+        """ prepare app and tour overlay (singleton instance of this class) to start tour.
 
         :param main_app:        main app instance.
         :param tour_class:      optional tour (pages) class, default: tour class of current help id or OnboardingTour.
